@@ -1,4 +1,4 @@
-; $Id: ruli-test.scm,v 1.2 2004/08/13 23:27:34 evertonm Exp $
+; $Id: ruli-test.scm,v 1.3 2004/08/26 17:09:47 evertonm Exp $
 
 ; with optional argument
 (ruli-sync-query "_http._tcp" "isc.org" -1 0)
@@ -8,8 +8,6 @@
 (ruli-sync-query "_http._tcp" "isc.org" -1)
 (ruli-sync-smtp-query "isc.org")
 
-(ruli-sync-smtp-query "aol.com")
-
 (define sample-srv-list 
   '(
     ( (target "host1.domain")
@@ -29,5 +27,11 @@
 (use-modules (ice-9 readline))
 (activate-readline)
 
-; run test
-(ruli-test)
+; write query result to file
+(define result '())
+(define out '())
+(set! result (ruli-sync-smtp-query "aol.com"))
+(set! out (open-output-file "result.txt"))
+(write-line result out)
+(close out)
+
