@@ -1,5 +1,5 @@
 /*
-  $Id: php_ruli.c,v 1.2 2004/03/18 16:07:56 evertonm Exp $ 
+  $Id: php_ruli.c,v 1.6 2004/10/25 05:47:16 evertonm Exp $ 
 */
 
 #ifdef HAVE_CONFIG_H
@@ -27,7 +27,8 @@ static int le_ruli;
 function_entry ruli_functions[] = {
 	PHP_FE(confirm_ruli_compiled,	NULL)		/* For testing, remove later. */
 	PHP_FE(ruli_sync_query,	NULL)
-	PHP_FE(ruli_sync_smtp_query,	NULL)
+	PHP_FE(ruli_sync_smtp_query, NULL)
+	PHP_FE(ruli_sync_http_query, NULL)
 	{NULL, NULL, NULL}	/* Must be the last line in ruli_functions[] */
 };
 /* }}} */
@@ -46,7 +47,7 @@ zend_module_entry ruli_module_entry = {
 	PHP_RSHUTDOWN(ruli),	/* Replace with NULL if there's nothing to do at request end */
 	PHP_MINFO(ruli),
 #if ZEND_MODULE_API_NO >= 20010901
-	"0.1", /* Replace with version number for your extension */
+	"0.2", /* Replace with version number for your extension */
 #endif
 	STANDARD_MODULE_PROPERTIES
 };
@@ -160,6 +161,84 @@ PHP_FUNCTION(confirm_ruli_compiled)
    follow this convention for the convenience of others editing your code.
 */
 
+static int scan_srv_list(zval *return_value, ruli_sync_t *sync_query)
+{
+	int srv_code;
+	ruli_list_t *srv_list;
+	int srv_list_size;
+	int i;
+
+	/*
+	 * Underlying SRV query failure?
+	 */
+	srv_code = ruli_sync_srv_code(sync_query);
+	if (srv_code == RULI_SRV_CODE_ALARM)
+		return -1;
+
+	/*
+	 * Service provided?
+	 */
+	if (srv_code == RULI_SRV_CODE_UNAVAILABLE)
+		return -1;
+
+	/*
+	 * Server RCODE?
+	 */
+	if (srv_code) {
+		int rcode = ruli_sync_rcode(sync_query);
+		if (rcode)
+			return -1;
+
+		return -1;
+	}
+
+	srv_list = ruli_sync_srv_list(sync_query);
+	srv_list_size = ruli_list_size(srv_list);
+
+	/*
+	 * Scan list of SRV records
+	 */
+	array_init(return_value);
+	for (i = 0; i < srv_list_size; ++i) {
+		ruli_srv_entry_t *entry         = ruli_list_get(srv_list, i);
+		ruli_list_t      *addr_list     = &entry->addr_list;
+		int              addr_list_size = ruli_list_size(addr_list);
+		char             txt_dname_buf[RULI_LIMIT_DNAME_TEXT_BUFSZ];
+		int              txt_dname_len;
+		int              j;
+		zval             *srv;
+		zval		     *srv_addrs;
+
+		if (ruli_dname_decode(txt_dname_buf, RULI_LIMIT_DNAME_TEXT_BUFSZ,
+							  &txt_dname_len,
+							  entry->target, entry->target_len))
+			continue;
+
+		MAKE_STD_ZVAL(srv);
+		array_init(srv);
+		add_index_zval(return_value, i, srv);
+
+		add_assoc_string(srv, "target", txt_dname_buf, 1);
+		add_assoc_long(srv, "priority", entry->priority);
+		add_assoc_long(srv, "weight", entry->weight);
+		add_assoc_long(srv, "port", entry->port);
+
+		MAKE_STD_ZVAL(srv_addrs);
+		array_init(srv_addrs);
+		add_assoc_zval(srv, "addr_list", srv_addrs);
+
+		for (j = 0; j < addr_list_size; ++j) {
+			ruli_addr_t *addr = ruli_list_get(addr_list, j);
+			char buf[40];
+			if (ruli_addr_snprint(buf, 40, addr) < 0)
+				continue;
+			add_index_string(srv_addrs, j, buf, 1);
+		}
+	}
+
+	return 0;
+}
+
 /* {{{ proto array ruli_sync_query(string service, string domain, int fallback_port, long options)
    query SRV records synchronously */
 PHP_FUNCTION(ruli_sync_query)
@@ -173,10 +252,6 @@ PHP_FUNCTION(ruli_sync_query)
 	long options;
 
 	ruli_sync_t *sync_query;
-	int srv_code;
-	ruli_list_t *srv_list;
-	int srv_list_size;
-	int i;
 
 	if (zend_parse_parameters(argc TSRMLS_CC, "ssll", &service, &service_len, &domain, &domain_len, &fallback_port, &options) == FAILURE) 
 		return;
@@ -189,79 +264,16 @@ PHP_FUNCTION(ruli_sync_query)
 		RETURN_FALSE;
 	}
 
-	/*
-	 * Underlying SRV query failure?
-	 */
-	srv_code = ruli_sync_srv_code(sync_query);
-	if (srv_code == RULI_SRV_CODE_ALARM) {
-		ruli_sync_delete(sync_query);
-		RETURN_FALSE;
-	}
+	{
+		int result;
+		result = scan_srv_list(return_value, sync_query);
 
-	/*
-	 * Service provided?
-	 */
-	if (srv_code == RULI_SRV_CODE_UNAVAILABLE) {
 		ruli_sync_delete(sync_query);
-		RETURN_FALSE;
-	}
 
-	/*
-	 * Server RCODE?
-	 */
-	if (srv_code) {
-		int rcode = ruli_sync_rcode(sync_query);
-		if (rcode) {
-			ruli_sync_delete(sync_query);
+		if (result) {
 			RETURN_FALSE;
 		}
-
-		ruli_sync_delete(sync_query);
-		RETURN_FALSE;
 	}
-
-	srv_list = ruli_sync_srv_list(sync_query);
-	srv_list_size = ruli_list_size(srv_list);
-
-	/*
-	 * Scan list of SRV records
-	 */
-	array_init(return_value);
-	for (i = 0; i < srv_list_size; ++i) {
-		ruli_srv_entry_t *entry         = ruli_list_get(srv_list, i);
-		ruli_list_t      *addr_list     = &entry->addr_list;
-		int              addr_list_size = ruli_list_size(addr_list);
-		char             txt_dname_buf[RULI_LIMIT_DNAME_TEXT_BUFSZ];
-		int              txt_dname_len;
-		int              j;
-		zval             *srv;
-		zval		 *srv_addrs;
-
-		if (ruli_dname_decode(txt_dname_buf, RULI_LIMIT_DNAME_TEXT_BUFSZ,
-	       		&txt_dname_len,
-			entry->target, entry->target_len))
-			continue;
-
-		MAKE_STD_ZVAL(srv);
-		array_init(srv);
-		add_index_zval(return_value, i, srv);
-
-		add_assoc_string(srv, "target", txt_dname_buf, 1);
-		add_assoc_long(srv, "priority", entry->priority);
-		add_assoc_long(srv, "weight", entry->weight);
-		add_assoc_long(srv, "port", entry->port);
-
-		MAKE_STD_ZVAL(srv_addrs);
-		array_init(srv_addrs);
-		add_assoc_zval(srv, "addr_list", srv_addrs);
-
-		for (j = 0; j < addr_list_size; ++j) {
-			struct in_addr *addr = ruli_list_get(addr_list, j);
-			add_index_string(srv_addrs, j, inet_ntoa(*addr), 1);
-		}
-	}
-
-	ruli_sync_delete(sync_query);
 }
 /* }}} */
 
@@ -275,10 +287,6 @@ PHP_FUNCTION(ruli_sync_smtp_query)
 	long options;
 
 	ruli_sync_t *sync_query;
-	int srv_code;
-	ruli_list_t *srv_list;
-	int srv_list_size;
-	int i;
 
 	if (zend_parse_parameters(argc TSRMLS_CC, "sl", &domain, &domain_len, &options) == FAILURE) 
 		return;
@@ -291,79 +299,52 @@ PHP_FUNCTION(ruli_sync_smtp_query)
 		RETURN_FALSE;
 	}
 
-	/*
-	 * Underlying SRV query failure?
-	 */
-	srv_code = ruli_sync_srv_code(sync_query);
-	if (srv_code == RULI_SRV_CODE_ALARM) {
-		ruli_sync_delete(sync_query);
-		RETURN_FALSE;
-	}
+	{
+		int result;
+		result = scan_srv_list(return_value, sync_query);
 
-	/*
-	 * Service provided?
-	 */
-	if (srv_code == RULI_SRV_CODE_UNAVAILABLE) {
 		ruli_sync_delete(sync_query);
-		RETURN_FALSE;
-	}
-
-	/*
-	 * Server RCODE?
-	 */
-	if (srv_code) {
-		int rcode = ruli_sync_rcode(sync_query);
-		if (rcode) {
-			ruli_sync_delete(sync_query);
+		
+		if (result) {
 			RETURN_FALSE;
 		}
+	}
+}
+/* }}} */
 
-		ruli_sync_delete(sync_query);
+/* {{{ proto array ruli_sync_http_query(string domain, int force_port, long options)
+   query SRV records synchronously for _http._tcp service */
+PHP_FUNCTION(ruli_sync_http_query)
+{
+	char *domain = NULL;
+	int argc = ZEND_NUM_ARGS();
+	int domain_len;
+	long force_port;
+	long options;
+
+	ruli_sync_t *sync_query;
+
+	if (zend_parse_parameters(argc TSRMLS_CC, "sll", &domain, &domain_len, &force_port, &options) == FAILURE) 
+		return;
+
+	/*
+	 * Submit query
+	 */
+	sync_query = ruli_sync_http_query(domain, force_port, options);
+	if (!sync_query) {
 		RETURN_FALSE;
 	}
 
-	srv_list = ruli_sync_srv_list(sync_query);
-	srv_list_size = ruli_list_size(srv_list);
-
-	/*
-	 * Scan list of SRV records
-	 */
-	array_init(return_value);
-	for (i = 0; i < srv_list_size; ++i) {
-		ruli_srv_entry_t *entry         = ruli_list_get(srv_list, i);
-		ruli_list_t      *addr_list     = &entry->addr_list;
-		int              addr_list_size = ruli_list_size(addr_list);
-		char             txt_dname_buf[RULI_LIMIT_DNAME_TEXT_BUFSZ];
-		int              txt_dname_len;
-		int              j;
-		zval             *srv;
-		zval		 *srv_addrs;
-
-		if (ruli_dname_decode(txt_dname_buf, RULI_LIMIT_DNAME_TEXT_BUFSZ,
-	       		&txt_dname_len,
-			entry->target, entry->target_len))
-			continue;
-
-		MAKE_STD_ZVAL(srv);
-		array_init(srv);
-		add_index_zval(return_value, i, srv);
-
-		add_assoc_string(srv, "target", txt_dname_buf, 1);
-		add_assoc_long(srv, "priority", entry->priority);
-		add_assoc_long(srv, "weight", entry->weight);
-		add_assoc_long(srv, "port", entry->port);
-
-		MAKE_STD_ZVAL(srv_addrs);
-		array_init(srv_addrs);
-		add_assoc_zval(srv, "addr_list", srv_addrs);
-
-		for (j = 0; j < addr_list_size; ++j) {
-			struct in_addr *addr = ruli_list_get(addr_list, j);
-			add_index_string(srv_addrs, j, inet_ntoa(*addr), 1);
+	{
+		int result;
+		result = scan_srv_list(return_value, sync_query);
+		
+		ruli_sync_delete(sync_query);
+		
+		if (result) {
+			RETURN_FALSE;
 		}
 	}
-
-	ruli_sync_delete(sync_query);
 }
 /* }}} */
 
