@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_fsm.c,v 1.23 2004/06/08 19:42:36 evertonm Exp $
+  $Id: ruli_fsm.c,v 1.26 2004/06/17 07:21:01 evertonm Exp $
 
 
   TIMEOUT NOTES:
@@ -107,7 +107,7 @@ static void *query_done(ruli_res_query_t *qry)
     if (qry->answer_header.flags & RULI_MSG_MASK_TC)
       qry->answer_code = RULI_CODE_ANSWER_TRUNC;
 
-  return fsm_query_done(qry);
+  return _ruli_fsm_query_done(qry);
 }
 
 /*
@@ -191,7 +191,7 @@ static void *on_udp_read_timeout(oop_source *oop_src,
    * Switched
    */
 
-  query_want_write_udp(qry);
+  _ruli_query_want_write_udp(qry);
 
   return OOP_CONTINUE;
 }
@@ -265,7 +265,7 @@ static void query_switch_status(ruli_res_query_t *qry, int status)
   qry->status = status;
 }
 
-void query_want_write_udp(ruli_res_query_t *qry)
+void _ruli_query_want_write_udp(ruli_res_query_t *qry)
 {
   ruli_res_t *res_ctx = qry->resolver;
   oop_source *oop_src = res_ctx->res_source;
@@ -863,7 +863,7 @@ static void *on_udp_write(oop_source *oop_src, int udp_sd,
      * Switched
      */
 
-    query_want_write_udp(qry); 
+    _ruli_query_want_write_udp(qry); 
 
     return OOP_CONTINUE;
   }
@@ -882,7 +882,7 @@ static void *on_udp_write(oop_source *oop_src, int udp_sd,
 
 static void *start_tcp_query(ruli_res_query_t *qry)
 {
-  int tcp_sd = get_curr_tcp_socket(qry);
+  int tcp_sd = _ruli_get_curr_tcp_socket(qry);
 
   /*
    * If socket disconnected: Set wanna-connect mode
@@ -900,7 +900,7 @@ static void *start_tcp_query(ruli_res_query_t *qry)
   return OOP_CONTINUE;
 }
 
-static int check_answer_flags(ruli_uint16_t flags)
+static int check_answer_flags(ruli_uint16_t flags, long options)
 {
   /* We expect a query answer */
   if (!(flags & RULI_MSG_MASK_QR))
@@ -914,9 +914,10 @@ static int check_answer_flags(ruli_uint16_t flags)
   if (!(flags & RULI_MSG_MASK_RD))
     return RULI_CODE_ANSWER_FLAG_RD;
   
-  /* We require recursive service */
-  if (!(flags & RULI_MSG_MASK_RA))
-    return RULI_CODE_ANSWER_FLAG_RA;
+  /* Require recursive service? */
+  if (options & RULI_RES_OPT_NEED_RA) 
+    if (!(flags & RULI_MSG_MASK_RA))
+      return RULI_CODE_ANSWER_FLAG_RA;
   
   /* RFC1035 states Z must be zero, so be it */
   if (flags & RULI_MSG_MASK_Z)
@@ -1024,7 +1025,7 @@ static void *on_udp_read(oop_source *oop_src, int udp_sd,
    * Check answer flags
    */
   {
-    int code = check_answer_flags(msg_hdr.flags);
+    int code = check_answer_flags(msg_hdr.flags, qry->q_options);
 
     if (code) {
       qry->answer_code = code;
@@ -1272,7 +1273,7 @@ static void *on_tcp_write(oop_source *oop_src, int tcp_sd,
 {
   ruli_res_t       *res_ctx = (ruli_res_t *) ctx;
   int              result;
-  ruli_res_query_t *qry;
+  ruli_res_query_t *qry = 0; /* picky compilers */
   int              i;
   int              queries;
 
@@ -1465,7 +1466,7 @@ static void *recv_tcp_head(ruli_res_t *ctx, int tcp_sd)
    * Check answer flags
    */
   {
-    int code = check_answer_flags(msg_hdr.flags);
+    int code = check_answer_flags(msg_hdr.flags, qry->q_options);
 
     if (code) {
       qry->answer_code = code;
@@ -1521,7 +1522,7 @@ static void *recv_tcp_body(ruli_res_query_t *qry, int tcp_sd)
 	  qry->query_id, qry->resolver_index);
 #endif
 
-  assert(get_curr_tcp_socket(qry) == tcp_sd);
+  assert(_ruli_get_curr_tcp_socket(qry) == tcp_sd);
   assert(qry->answer_buf);
   assert(qry->answer_buf_size >= RULI_LIMIT_MSG_LOW);
   assert(qry->answer_msg_len >= RULI_LIMIT_MSG_HEADER);
@@ -1621,7 +1622,7 @@ static void *on_tcp_read(oop_source *oop_src, int tcp_sd,
   for (i = 0; i < list_size; ++i) {
     qry = (ruli_res_query_t *) ruli_list_get(query_list, i);
 
-    if (get_curr_tcp_socket(qry) == tcp_sd)
+    if (_ruli_get_curr_tcp_socket(qry) == tcp_sd)
       if (qry->status == RULI_QRY_STAT_TCP_WANT_RECV_BODY)
 	break;
   }
@@ -1638,7 +1639,7 @@ static void *on_tcp_read(oop_source *oop_src, int tcp_sd,
   return recv_tcp_head(res_ctx, tcp_sd);
 }
 
-void query_status_done(ruli_res_query_t *qry)
+void _ruli_query_status_done(ruli_res_query_t *qry)
 {
   switch (qry->status) {
   case RULI_QRY_STAT_VOID:
