@@ -16,7 +16,7 @@
  */
 
 /*
-  $Id: ruli_getaddrinfo.c,v 1.11 2004/08/25 19:04:23 evertonm Exp $
+  $Id: ruli_getaddrinfo.c,v 1.13 2005/06/06 22:57:02 evertonm Exp $
 */
 
 
@@ -88,6 +88,7 @@ int ruli_getaddrinfo(const char *node, const char *service,
   struct addrinfo *res = NULL, *res0 = NULL, *res1 = NULL;
   char full_service[RULI_LIMIT_DNAME_TEXT_BUFSZ];
   int srv_code, srv_list_size, i;
+  long options = RULI_RES_OPT_SEARCH | RULI_RES_OPT_SRV_RFC3484;
 
   if (!node || (node && !*node) ||
       !service || (service && !*service) || !hints || !_res)
@@ -107,8 +108,13 @@ int ruli_getaddrinfo(const char *node, const char *service,
     snprintf(full_service, RULI_LIMIT_DNAME_TEXT_BUFSZ, "_%s._udp", service);
   else
     return call_getaddrinfo(node, service, hints, _res);
+
+  if (hints->ai_family == AF_INET)
+    options |= RULI_RES_OPT_SRV_NOINET6;
+  else if (hints->ai_family == AF_INET6)
+    options |= RULI_RES_OPT_SRV_NOINET;
 	
-  query = ruli_sync_query(full_service, node, -1, RULI_RES_OPT_SEARCH);
+  query = ruli_sync_query(full_service, node, -1, options);
   if (!query)
     return call_getaddrinfo(node, service, hints, _res);
 
