@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_getaddrinfo.h,v 1.2 2004/06/05 19:42:31 evertonm Exp $
+  $Id: ruli_getaddrinfo.h,v 1.3 2004/08/25 22:25:57 evertonm Exp $
   */
 
 
@@ -27,6 +27,10 @@ Boston, MA 02111-1307, USA.
 #define RULI_GETADDRINFO
 
 
+#ifndef __USE_POSIX
+#define __USE_POSIX
+#endif
+
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netdb.h>
