@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_host.h,v 1.2 2004/06/25 16:31:05 evertonm Exp $
+  $Id: ruli_host.h,v 1.3 2004/06/28 19:19:29 evertonm Exp $
   */
 
 
@@ -91,12 +91,6 @@ const char *ruli_host_errstr(int result);
 int ruli_host_answer_code(ruli_host_t *host_qry);
 int ruli_host_rcode(ruli_host_t *host_qry);
 
-/*
- * misc utilities
- */
-int _ruli_reset_qtype(long options);
-int _ruli_need_query_in_a(int qtype, long options);
-
 
 #endif /* RULI_HOST_H */
 
