@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_res.c,v 1.35 2004/08/25 19:04:23 evertonm Exp $
+  $Id: ruli_res.c,v 1.36 2004/10/06 04:25:59 evertonm Exp $
   */
 
 
@@ -717,7 +717,8 @@ static const ruli_domain_t *next_search_suffix(ruli_res_query_t *qry)
   assert(qry->search_index >= 0);
   assert(qry->search_index < search_list_size);
 
-  suffix = (ruli_domain_t *) ruli_list_get(res_ctx->search_list, qry->search_index);
+  suffix = (ruli_domain_t *) ruli_list_get(res_ctx->search_list, 
+					   qry->search_index);
 
   return suffix;
 }
