@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_smtp.c,v 1.19 2004/10/07 19:25:08 evertonm Exp $
+  $Id: ruli_smtp.c,v 1.20 2005/06/06 22:57:02 evertonm Exp $
   */
 
 
@@ -37,14 +37,6 @@ Boston, MA 02111-1307, USA.
 
 static int srv_cmp_priority(const void *srv1, const void *srv2)
 {
-  /*
-  const ruli_srv_entry_t * const *s1 = (const ruli_srv_entry_t * const *) srv1;
-  const ruli_srv_entry_t * const *s2 = (const ruli_srv_entry_t * const *) srv2;
-
-  const ruli_srv_entry_t *e1 = (const ruli_srv_entry_t *) *s1;
-  const ruli_srv_entry_t *e2 = (const ruli_srv_entry_t *) *s2;
-  */
-
   const ruli_srv_entry_t *e1 = *(const ruli_srv_entry_t * const *) srv1;
   const ruli_srv_entry_t *e2 = *(const ruli_srv_entry_t * const *) srv2;
 
