@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_srv.c,v 1.78 2004/10/08 04:22:15 evertonm Exp $
+  $Id: ruli_srv.c,v 1.85 2005/06/16 16:55:38 evertonm Exp $
   */
 
 
@@ -30,6 +30,7 @@ Boston, MA 02111-1307, USA.
 
 #include <assert.h>
 #include <string.h>
+#include <stdlib.h>
 
 #include <ruli_srv.h>
 #include <ruli_parse.h>
@@ -44,7 +45,7 @@ const char *ruli_srv_errstr(int result)
   return "FIXME: ruli_srv_errstr()";
 }
 
-static void sort_by_addr_family(ruli_list_t *srv_list)
+static void addr_selection(ruli_list_t *srv_list, long options)
 {
   int i;
   int srv_list_size = ruli_list_size(srv_list);
@@ -52,26 +53,8 @@ static void sort_by_addr_family(ruli_list_t *srv_list)
   /* scan srv entries */
   for (i = 0; i < srv_list_size; ++i) {
     ruli_srv_entry_t *entry = (ruli_srv_entry_t *) ruli_list_get(srv_list, i);
-    ruli_list_t *addr_list = &entry->addr_list;
-    int j = 0;
-    int k = ruli_list_size(addr_list) - 1;
 
-    /* sort addresses by family */
-    while (j < k) {
-      while ((j < k) && ruli_addr_family((ruli_addr_t *) ruli_list_get(addr_list, j)) == PF_INET6)
-	++j;
-      while ((j < k) && ruli_addr_family((ruli_addr_t *) ruli_list_get(addr_list, k)) == PF_INET)
-	--k;
-
-      /* swap? */
-      if (j < k) {
-	void *tmp = ruli_list_get(addr_list, j);
-	ruli_list_set(addr_list, j, ruli_list_get(addr_list, k));
-	ruli_list_set(addr_list, k, tmp);
-	++j;
-	--k;
-      }
-    }
+    ruli_addr_rfc3484_sort(&entry->addr_list, options);
   }
 }
 
@@ -85,10 +68,9 @@ void *_ruli_srv_query_done(ruli_srv_t *srv_qry, int srv_result_code)
 
   srv_qry->answer_code = srv_result_code;
 
-  /* Move IPv6 addresses to begin ? */
+  /* Sort addresses */
   if (srv_result_code == RULI_SRV_CODE_OK)
-    if (!(srv_qry->srv_options & RULI_RES_OPT_SRV_NOSORT6))
-      sort_by_addr_family(&srv_qry->answer_srv_list);
+    addr_selection(&srv_qry->answer_srv_list, srv_qry->srv_options);
 
   /*
    * Invoke srv user callback
