@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_sync.c,v 1.26 2004/10/04 06:52:05 evertonm Exp $
+  $Id: ruli_sync.c,v 1.27 2004/10/08 04:22:15 evertonm Exp $
  */
 
 
@@ -37,6 +37,7 @@ Boston, MA 02111-1307, USA.
 #include <ruli_mem.h>
 #include <ruli_conf.h>
 #include <ruli_smtp.h>
+#include <ruli_http.h>
 
 
 static void *on_search_answer(ruli_search_srv_t *search, void *search_arg)
@@ -219,6 +220,96 @@ ruli_sync_t *ruli_sync_smtp_query(const char *txt_domain, long options)
   return syn_qry;
 }
 
+/*
+ * This query uses fallback to address
+ * records as implicit fallback mechanism.
+ */
+ruli_sync_t *ruli_sync_http_query(const char *txt_domain, int port, 
+				  long options)
+{
+  oop_source_sys *source_sys;
+  oop_source     *source;
+  ruli_sync_t    *syn_qry;
+
+  /*
+   * Create event source
+   */
+
+  source_sys = oop_sys_new();
+  if (!source_sys)
+    return 0;
+
+  source = oop_sys_source(source_sys);
+  if (!source) {
+    oop_sys_delete(source_sys);
+    return 0;
+  }
+
+  /*
+   * Create sync query context
+   */
+
+  syn_qry = (ruli_sync_t *) ruli_malloc(sizeof(ruli_sync_t));
+  if (!syn_qry) {
+    oop_sys_delete(source_sys);
+    return 0;
+  }
+
+  /*
+   * Create search resolver context
+   */
+
+  syn_qry->search_res = ruli_search_res_new(source, 2, 10);
+  if (!syn_qry->search_res) {
+    oop_sys_delete(source_sys);
+    ruli_free(syn_qry);
+
+    return 0;
+  }
+
+  /*
+   * Submit query
+   */
+  {
+    ruli_res_t *res = ruli_search_resolver(syn_qry->search_res);
+
+    assert(res);
+
+    /*
+     * This query uses fallback to address
+     * records as implicit fallback mechanism.
+     */
+    syn_qry->search = ruli_search_http_submit(res,
+					      on_search_answer,
+					      syn_qry,
+					      port,
+					      options,
+					      txt_domain);
+    if (!syn_qry->search) {
+      assert(syn_qry->search_res);
+
+      ruli_search_res_delete(syn_qry->search_res);
+      oop_sys_delete(source_sys);
+      ruli_free(syn_qry);
+
+      return 0;
+    }
+  }
+
+  /*
+   * Run event loop
+   */
+  {
+    void *oop_result = oop_sys_run(source_sys);
+
+    assert(oop_result == OOP_CONTINUE);
+  }
+
+  oop_sys_delete(source_sys); /* destroy event source */
+
+  return syn_qry;
+}
+
 void ruli_sync_delete(ruli_sync_t *syn_qry)
 {
   assert(syn_qry);
