@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: addrsolver2.c,v 1.17 2004/06/23 19:47:29 evertonm Exp $
+  $Id: addrsolver2.c,v 1.18 2005/06/07 22:17:51 evertonm Exp $
  */
 
 
@@ -159,8 +159,7 @@ static void *on_answer(ruli_res_query_t *qry, void *arg)
 	if (result)
 	  continue;
 
-	addr.addr_family = PF_INET;
-	addr.addr_size = sizeof(addr.addr.ipv4);
+	ruli_addr_init(&addr, PF_INET);
 
 	break;
 
@@ -170,8 +169,7 @@ static void *on_answer(ruli_res_query_t *qry, void *arg)
 	if (result)
 	  continue;
 
-	addr.addr_family = PF_INET6;
-	addr.addr_size = sizeof(addr.addr.ipv6);
+	ruli_addr_init(&addr, PF_INET6);
 
 	break;
 
